@@ -8,7 +8,7 @@
 //! (even with zero features) under [`kube::core`]((https://docs.rs/kube/*/kube/core/index.html)).
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![deny(missing_docs)]
-#![deny(unsafe_code)]
+#![forbid(unsafe_code)]
 
 #[cfg_attr(docsrs, doc(cfg(feature = "admission")))]
 #[cfg(feature = "admission")]
@@ -42,6 +42,10 @@ pub use resource::{Resource, ResourceExt};
 pub mod response;
 pub use response::Status;
 
+#[cfg_attr(docsrs, doc(cfg(feature = "schema")))]
+#[cfg(feature = "schema")]
+pub mod schema;
+
 pub mod subresource;
 
 pub mod util;
@@ -51,3 +55,6 @@ pub use watch::WatchEvent;
 
 mod error;
 pub use error::ErrorResponse;
+
+mod version;
+pub use version::Version;
